<?php
/**
 * Plugin Name:           GamiPress - Modern Events Calendar integration
 * Plugin URI:            https://wordpress.org/plugins/gamipress-modern-events-calendar-integration/
 * Description:           Connect GamiPress with Modern Events Calendar.
 * Version:               1.0.0
 * Author:                GamiPress
 * Author URI:            https://gamipress.com/
 * Text Domain:           gamipress-modern-events-calendar-integration
 * Domain Path:           /languages/
 * Requires at least:     4.4
 * Tested up to:          6.2
 * License:               GNU AGPL v3.0 (http://www.gnu.org/licenses/agpl.txt)
 *
 * @package               GamiPress\Modern_Events_Calendar
 * @author                GamiPress
 * @copyright             Copyright (c) GamiPress
 */

final class GamiPress_Modern_Events_Calendar {

    /**
     * @var         GamiPress_Modern_Events_Calendar $instance The one true GamiPress_Modern_Events_Calendar
     * @since       1.0.0
     */
    private static $instance;

    /**
     * Get active instance
     *
     * @access      public
     * @since       1.0.0
     * @return      GamiPress_Modern_Events_Calendar self::$instance The one true GamiPress_Modern_Events_Calendar
     */
    public static function instance() {
        if( !self::$instance ) {
            self::$instance = new GamiPress_Modern_Events_Calendar();
            self::$instance->constants();
            self::$instance->includes();
            self::$instance->hooks();
            self::$instance->load_textdomain();
        }

        return self::$instance;
    }

    /**
     * Setup plugin constants
     *
     * @access      private
     * @since       1.0.0
     * @return      void
     */
    private function constants() {
        // Plugin version
        define( 'GAMIPRESS_MODERN_EVENTS_CALENDAR_VER', '1.0.0' );

        // Plugin path
        define( 'GAMIPRESS_MODERN_EVENTS_CALENDAR_DIR', plugin_dir_path( __FILE__ ) );

        // Plugin URL
        define( 'GAMIPRESS_MODERN_EVENTS_CALENDAR_URL', plugin_dir_url( __FILE__ ) );
    }

    /**
     * Include plugin files
     *
     * @access      private
     * @since       1.0.0
     * @return      void
     */
    private function includes() {

        if( $this->meets_requirements() ) {

            require_once GAMIPRESS_MODERN_EVENTS_CALENDAR_DIR . 'includes/listeners.php';
            require_once GAMIPRESS_MODERN_EVENTS_CALENDAR_DIR . 'includes/triggers.php';

        }
    }

    /**
     * Setup plugin hooks
     *
     * @access      private
     * @since       1.0.0
     * @return      void
     */
    private function hooks() {
        add_action( 'admin_notices', array( $this, 'admin_notices' ) );
    }

    /**
     * Plugin admin notices.
     *
     * @since  1.0.0
     */
    public function admin_notices() {

        if ( ! $this->meets_requirements() && ! defined( 'GAMIPRESS_ADMIN_NOTICES' ) ) : ?>

            <div id="message" class="notice notice-error is-dismissible">
                <p>
                    <?php printf(
                        __( 'GamiPress - Modern Events Calendar integration requires %s and %s in order to work. Please install and activate them.', 'gamipress-modern-events-calendar-integration' ),
                        '<a href="https://wordpress.org/plugins/gamipress/" target="_blank">GamiPress</a>',
                        '<a href="https://wordpress.org/plugins/modern-events-calendar-lite/" target="_blank">Modern Events Calendar</a>'
                    ); ?>
                </p>
            </div>

            <?php define( 'GAMIPRESS_ADMIN_NOTICES', true ); ?>

        <?php endif;

    }

    /**
     * Check if there are all plugin requirements
     *
     * @since  1.0.0
     *
     * @return bool True if installation meets all requirements
     */
    private function meets_requirements() {

        if ( ! class_exists( 'GamiPress' ) )
            return false;

        // Requirements on multisite install
        if( is_multisite() && gamipress_is_network_wide_active() && is_main_site() ) {
            // On main site, need to check if integrated plugin is installed on any sub site to load all configuration files
            if( gamipress_is_plugin_active_on_network( 'modern-events-calendar-lite/modern-events-calendar-lite.php' )
                || gamipress_is_plugin_active_on_network( 'modern-events-calendar/modern-events-calendar.php' ) )
                return true;
        }

        if ( ! class_exists( 'MEC' ) )
            return false;

        return true;

    }

    /**
     * Internationalization
     *
     * @access      public
     * @since       1.0.0
     * @return      void
     */
    public function load_textdomain() {

        // Set filter for language directory
        $lang_dir = GAMIPRESS_MODERN_EVENTS_CALENDAR_DIR . '/languages/';
        $lang_dir = apply_filters( 'gamipress_modern_events_calendar_languages_directory', $lang_dir );

        // Traditional WordPress plugin locale filter
        $locale = apply_filters( 'plugin_locale', get_locale(), 'gamipress-modern-events-calendar-integration' );
        $mofile = sprintf( '%1$s-%2$s.mo', 'gamipress-modern-events-calendar-integration', $locale );

        // Setup paths to current locale file
        $mofile_local   = $lang_dir . $mofile;
        $mofile_global  = WP_LANG_DIR . '/gamipress-modern-events-calendar-integration/' . $mofile;

        if( file_exists( $mofile_global ) ) {
            // Look in global /wp-content/languages/gamipress-modern-events-calendar-integration/ folder
            load_textdomain( 'gamipress-modern-events-calendar-integration', $mofile_global );
        } elseif( file_exists( $mofile_local ) ) {
            // Look in local /wp-content/plugins/gamipress-modern-events-calendar-integration/languages/ folder
            load_textdomain( 'gamipress-modern-events-calendar-integration', $mofile_local );
        } else {
            // Load the default language files
            load_plugin_textdomain( 'gamipress-modern-events-calendar-integration', false, $lang_dir );
        }

    }

}

/**
 * The main function responsible for returning the one true GamiPress_Modern_Events_Calendar instance to functions everywhere
 *
 * @since       1.0.0
 * @return      \GamiPress_Modern_Events_Calendar The one true GamiPress_Modern_Events_Calendar
 */
function GamiPress_Modern_Events_Calendar() {
    return GamiPress_Modern_Events_Calendar::instance();
}
add_action( 'plugins_loaded', 'GamiPress_Modern_Events_Calendar' );

